# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class GetObjectStorageSessionKeyResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_key': 'str',
        'endpoint': 'str',
        'secret_key': 'str',
        'session_name': 'str',
        'session_token': 'str'
    }

    attribute_map = {
        'access_key': 'accessKey',
        'endpoint': 'endpoint',
        'secret_key': 'secretKey',
        'session_name': 'sessionName',
        'session_token': 'sessionToken'
    }

    def __init__(self, access_key=None, endpoint=None, secret_key=None, session_name=None, session_token=None, _configuration=None):  # noqa: E501
        """GetObjectStorageSessionKeyResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._access_key = None
        self._endpoint = None
        self._secret_key = None
        self._session_name = None
        self._session_token = None
        self.discriminator = None

        if access_key is not None:
            self.access_key = access_key
        if endpoint is not None:
            self.endpoint = endpoint
        if secret_key is not None:
            self.secret_key = secret_key
        if session_name is not None:
            self.session_name = session_name
        if session_token is not None:
            self.session_token = session_token

    @property
    def access_key(self):
        """Gets the access_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The access_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this GetObjectStorageSessionKeyResponse.


        :param access_key: The access_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def endpoint(self):
        """Gets the endpoint of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The endpoint of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this GetObjectStorageSessionKeyResponse.


        :param endpoint: The endpoint of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def secret_key(self):
        """Gets the secret_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The secret_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """Sets the secret_key of this GetObjectStorageSessionKeyResponse.


        :param secret_key: The secret_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._secret_key = secret_key

    @property
    def session_name(self):
        """Gets the session_name of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The session_name of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._session_name

    @session_name.setter
    def session_name(self, session_name):
        """Sets the session_name of this GetObjectStorageSessionKeyResponse.


        :param session_name: The session_name of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._session_name = session_name

    @property
    def session_token(self):
        """Gets the session_token of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The session_token of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._session_token

    @session_token.setter
    def session_token(self, session_token):
        """Sets the session_token of this GetObjectStorageSessionKeyResponse.


        :param session_token: The session_token of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._session_token = session_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetObjectStorageSessionKeyResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetObjectStorageSessionKeyResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetObjectStorageSessionKeyResponse):
            return True

        return self.to_dict() != other.to_dict()
