# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.permissions_api import PermissionsApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestPermissionsApi(unittest.TestCase):
    """PermissionsApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.permissions_api.PermissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_billing_account_user_permission(self):
        """Test case for add_billing_account_user_permission

        Add billing account user  # noqa: E501
        """
        pass

    def test_add_data_center_user_permission(self):
        """Test case for add_data_center_user_permission

        Add data center user  # noqa: E501
        """
        pass

    def test_add_project_user_permission(self):
        """Test case for add_project_user_permission

        Add project user  # noqa: E501
        """
        pass

    def test_list_user_permissions(self):
        """Test case for list_user_permissions

        List  # noqa: E501
        """
        pass

    def test_remove_billing_account_user_permission(self):
        """Test case for remove_billing_account_user_permission

        Remove billing account user  # noqa: E501
        """
        pass

    def test_remove_data_center_user_permission(self):
        """Test case for remove_data_center_user_permission

        Remove data center user  # noqa: E501
        """
        pass

    def test_remove_project_user_permission(self):
        """Test case for remove_project_user_permission

        Remove project user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
