# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.object_storage_api import ObjectStorageApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestObjectStorageApi(unittest.TestCase):
    """ObjectStorageApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.object_storage_api.ObjectStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate(self):
        """Test case for activate

        Allow the use of S3 compatible storage in a project  # noqa: E501
        """
        pass

    def test_create_object_storage_user(self):
        """Test case for create_object_storage_user

        Create user that stores keys for storage buckets  # noqa: E501
        """
        pass

    def test_delete_object_storage_key(self):
        """Test case for delete_object_storage_key

        Delete object storage user  # noqa: E501
        """
        pass

    def test_delete_object_storage_user(self):
        """Test case for delete_object_storage_user

        Delete object storage user  # noqa: E501
        """
        pass

    def test_generate_object_storage_key(self):
        """Test case for generate_object_storage_key

        Generate access key for storage buckets  # noqa: E501
        """
        pass

    def test_get_object_storage_bucket(self):
        """Test case for get_object_storage_bucket

        Get details for a bucket  # noqa: E501
        """
        pass

    def test_get_object_storage_session_key(self):
        """Test case for get_object_storage_session_key

        Generate temporary key for storage bucket access  # noqa: E501
        """
        pass

    def test_list_object_storage_buckets(self):
        """Test case for list_object_storage_buckets

        List buckets  # noqa: E501
        """
        pass

    def test_list_object_storage_keys(self):
        """Test case for list_object_storage_keys

        List storage user keys  # noqa: E501
        """
        pass

    def test_list_object_storage_users(self):
        """Test case for list_object_storage_users

        List storage users  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
