# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.networks_api import NetworksApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestNetworksApi(unittest.TestCase):
    """NetworksApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.networks_api.NetworksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_network(self):
        """Test case for create_network

        Create network  # noqa: E501
        """
        pass

    def test_create_security_group(self):
        """Test case for create_security_group

        Create security group  # noqa: E501
        """
        pass

    def test_delete_network(self):
        """Test case for delete_network

        Delete network  # noqa: E501
        """
        pass

    def test_delete_security_group(self):
        """Test case for delete_security_group

        Delete security group  # noqa: E501
        """
        pass

    def test_get_network(self):
        """Test case for get_network

        Get network  # noqa: E501
        """
        pass

    def test_get_security_group(self):
        """Test case for get_security_group

        Get a security group  # noqa: E501
        """
        pass

    def test_list_networks(self):
        """Test case for list_networks

        List networks  # noqa: E501
        """
        pass

    def test_list_security_groups(self):
        """Test case for list_security_groups

        List security groups  # noqa: E501
        """
        pass

    def test_start_network(self):
        """Test case for start_network

        Start network  # noqa: E501
        """
        pass

    def test_stop_network(self):
        """Test case for stop_network

        Stop network  # noqa: E501
        """
        pass

    def test_update_security_group(self):
        """Test case for update_security_group

        Update security group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
