# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.disks_api import DisksApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestDisksApi(unittest.TestCase):
    """DisksApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.disks_api.DisksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_storage_disk(self):
        """Test case for attach_storage_disk

        Attach storage disk to VM  # noqa: E501
        """
        pass

    def test_create_disk_snapshot(self):
        """Test case for create_disk_snapshot

        Create Disk Snapshot  # noqa: E501
        """
        pass

    def test_create_storage_disk(self):
        """Test case for create_storage_disk

        Create storage disk  # noqa: E501
        """
        pass

    def test_delete_disk_snapshot(self):
        """Test case for delete_disk_snapshot

        Delete Disk Snapshots  # noqa: E501
        """
        pass

    def test_delete_storage_disk(self):
        """Test case for delete_storage_disk

        Delete storage disk  # noqa: E501
        """
        pass

    def test_detach_storage_disk(self):
        """Test case for detach_storage_disk

        Detach storage disk from VM  # noqa: E501
        """
        pass

    def test_get_disk(self):
        """Test case for get_disk

        List disks  # noqa: E501
        """
        pass

    def test_list_disk_snapshots(self):
        """Test case for list_disk_snapshots

        List Disk Snapshots  # noqa: E501
        """
        pass

    def test_list_disks(self):
        """Test case for list_disks

        List disks  # noqa: E501
        """
        pass

    def test_revert_disk(self):
        """Test case for revert_disk

        Revert Disk to Snapshot  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
