# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.user_api import UserApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_identity_verification_session(self):
        """Test case for create_identity_verification_session

        Get identity verification session  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
