# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.models.list_private_vm_images_response_private_image import ListPrivateVMImagesResponsePrivateImage  # noqa: E501
from cudo_compute.rest import ApiException


class TestListPrivateVMImagesResponsePrivateImage(unittest.TestCase):
    """ListPrivateVMImagesResponsePrivateImage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListPrivateVMImagesResponsePrivateImage(self):
        """Test ListPrivateVMImagesResponsePrivateImage"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cudo_compute.models.list_private_vm_images_response_private_image.ListPrivateVMImagesResponsePrivateImage()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
