# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class PaymentMethodCard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brand': 'str',
        'country': 'str',
        'exp_month': 'str',
        'exp_year': 'str',
        'fingerprint': 'str',
        'last4': 'str'
    }

    attribute_map = {
        'brand': 'brand',
        'country': 'country',
        'exp_month': 'expMonth',
        'exp_year': 'expYear',
        'fingerprint': 'fingerprint',
        'last4': 'last4'
    }

    def __init__(self, brand=None, country=None, exp_month=None, exp_year=None, fingerprint=None, last4=None, _configuration=None):  # noqa: E501
        """PaymentMethodCard - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._brand = None
        self._country = None
        self._exp_month = None
        self._exp_year = None
        self._fingerprint = None
        self._last4 = None
        self.discriminator = None

        if brand is not None:
            self.brand = brand
        if country is not None:
            self.country = country
        if exp_month is not None:
            self.exp_month = exp_month
        if exp_year is not None:
            self.exp_year = exp_year
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if last4 is not None:
            self.last4 = last4

    @property
    def brand(self):
        """Gets the brand of this PaymentMethodCard.  # noqa: E501


        :return: The brand of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this PaymentMethodCard.


        :param brand: The brand of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def country(self):
        """Gets the country of this PaymentMethodCard.  # noqa: E501


        :return: The country of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this PaymentMethodCard.


        :param country: The country of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def exp_month(self):
        """Gets the exp_month of this PaymentMethodCard.  # noqa: E501


        :return: The exp_month of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """Sets the exp_month of this PaymentMethodCard.


        :param exp_month: The exp_month of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """Gets the exp_year of this PaymentMethodCard.  # noqa: E501


        :return: The exp_year of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """Sets the exp_year of this PaymentMethodCard.


        :param exp_year: The exp_year of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._exp_year = exp_year

    @property
    def fingerprint(self):
        """Gets the fingerprint of this PaymentMethodCard.  # noqa: E501


        :return: The fingerprint of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this PaymentMethodCard.


        :param fingerprint: The fingerprint of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def last4(self):
        """Gets the last4 of this PaymentMethodCard.  # noqa: E501


        :return: The last4 of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """Sets the last4 of this PaymentMethodCard.


        :param last4: The last4 of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._last4 = last4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentMethodCard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMethodCard):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentMethodCard):
            return True

        return self.to_dict() != other.to_dict()
