# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.billing_api import BillingApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestBillingApi(unittest.TestCase):
    """BillingApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.billing_api.BillingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_billing_account(self):
        """Test case for create_billing_account

        Create a billing account  # noqa: E501
        """
        pass

    def test_delete_billing_account(self):
        """Test case for delete_billing_account

        Delete billing account  # noqa: E501
        """
        pass

    def test_get_billing_account(self):
        """Test case for get_billing_account

        Get a billing account  # noqa: E501
        """
        pass

    def test_get_billing_account_details(self):
        """Test case for get_billing_account_details

        Get billing account details  # noqa: E501
        """
        pass

    def test_get_billing_account_payment_methods(self):
        """Test case for get_billing_account_payment_methods

        Get payment methods  # noqa: E501
        """
        pass

    def test_get_billing_account_setup_intent(self):
        """Test case for get_billing_account_setup_intent

        Get setup intent  # noqa: E501
        """
        pass

    def test_get_billing_account_spend_details(self):
        """Test case for get_billing_account_spend_details

        Get spend details  # noqa: E501
        """
        pass

    def test_get_billing_account_stripe_invoices(self):
        """Test case for get_billing_account_stripe_invoices

        Get invoices  # noqa: E501
        """
        pass

    def test_list_billing_accounts(self):
        """Test case for list_billing_accounts

        List billing accounts  # noqa: E501
        """
        pass

    def test_list_outstanding_stripe_invoices(self):
        """Test case for list_outstanding_stripe_invoices

        Get outstanding invoices  # noqa: E501
        """
        pass

    def test_remove_billing_account_payment_method(self):
        """Test case for remove_billing_account_payment_method

        Remove payment method  # noqa: E501
        """
        pass

    def test_set_billing_account_default_payment_method(self):
        """Test case for set_billing_account_default_payment_method

        Set default payment method  # noqa: E501
        """
        pass

    def test_update_billing_account(self):
        """Test case for update_billing_account

        Update billing account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
