# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.models.list_disk_snapshots_response import ListDiskSnapshotsResponse  # noqa: E501
from cudo_compute.rest import ApiException


class TestListDiskSnapshotsResponse(unittest.TestCase):
    """ListDiskSnapshotsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListDiskSnapshotsResponse(self):
        """Test ListDiskSnapshotsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cudo_compute.models.list_disk_snapshots_response.ListDiskSnapshotsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
