# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.data_centers_api import DataCentersApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestDataCentersApi(unittest.TestCase):
    """DataCentersApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.data_centers_api.DataCentersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_hosts(self):
        """Test case for count_hosts

        Get host count  # noqa: E501
        """
        pass

    def test_create_data_center(self):
        """Test case for create_data_center

        Create data center  # noqa: E501
        """
        pass

    def test_delete_data_center(self):
        """Test case for delete_data_center

        Delete data center  # noqa: E501
        """
        pass

    def test_get_data_center(self):
        """Test case for get_data_center

        Get data center  # noqa: E501
        """
        pass

    def test_get_data_center_live_utilization(self):
        """Test case for get_data_center_live_utilization

        Get live utilization  # noqa: E501
        """
        pass

    def test_get_data_center_revenue_by_resource(self):
        """Test case for get_data_center_revenue_by_resource

        Get revenue by resource  # noqa: E501
        """
        pass

    def test_get_data_center_revenue_time_series(self):
        """Test case for get_data_center_revenue_time_series

        Get revenue time series  # noqa: E501
        """
        pass

    def test_list_clusters(self):
        """Test case for list_clusters

        List clusters  # noqa: E501
        """
        pass

    def test_list_data_centers(self):
        """Test case for list_data_centers

        List data centers  # noqa: E501
        """
        pass

    def test_list_hosts(self):
        """Test case for list_hosts

        List hosts  # noqa: E501
        """
        pass

    def test_update_data_center(self):
        """Test case for update_data_center

        Update data center  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
