# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.projects_api import ProjectsApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.projects_api.ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_project(self):
        """Test case for create_project

        Create  # noqa: E501
        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        Delete  # noqa: E501
        """
        pass

    def test_get_project(self):
        """Test case for get_project

        Get  # noqa: E501
        """
        pass

    def test_list_project_ssh_keys(self):
        """Test case for list_project_ssh_keys

        List SSH keys  # noqa: E501
        """
        pass

    def test_list_projects(self):
        """Test case for list_projects

        List  # noqa: E501
        """
        pass

    def test_update_project(self):
        """Test case for update_project

        Update  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
